# Release Notes


## Version 0.1.1 (in progress)

### Fixed
- Corrected labels for symmetric atlas hemisphere stack generation

### Added
- hemisphere values as `Atlas` class attributes


## Version 0.1.0

First release of the BrainGlobe `bg-atlasapi` package! :tada:

### Added
- Atlas metadata, reference stacks, region hierarchy
- Configuration tools
- Atlas download and updating
